#!-*-coding:utf-8-*-
import os
import sys
import numpy as np
import matplotlib.pyplot as plt

plt.rcParams["font.family"] = "IPAexGothic"


__all__ = ["hist"]

def hist( data , save=False , path=False ):
    """
    """
    y = list( data.values() )
    x = list( data.keys() )
    plt.bar( np.array( range( len( x ) ) ) , y )
    plt.xticks( np.array( range( len( x ) ) ) , x )

    if save and path:
        plt.savefig( path + "/tf_hist.png" )
    else:
        plt.show()



#!-*-coding:utf-8-*-
import numpy as np

__all__ = []
__all__ += ["unique","group_hist"]

def unique( mat ):
    """
    Get unique mat
    """
    return np.unique( mat )


def group_hist( mat ):
    """
    Get histgram in matrix
    """
    hist = {}
    matrix = unique( mat )
    if np.array( mat ).ndim >= 2:
        for unq in matrix:
            hist[unq] = 0
            for m in mat:
                hist[unq] += m.count(unq)
    else:
        for unq in matrix:
            hist[unq] = mat.count( unq )

    return hist



#!-*-coding:utf-8-*-
__all__ = ["S3"]

import os
import sys
import boto
import boto3
from colorama import Fore, Back, Style
from progressbar import ProgressBar
from boto.s3.key import Key

class S3:
    """
    S3に接続し、各種機能を提供するクラス
    """

    def __init__( self , profile=None , BUCKET_NAME=None ):
        if profile:
            from boto3.session import Session
            session = Session(profile_name=profile)
            self.s3 = session.resource('s3')
        else:
            self.s3 = boto3.resource('s3')

        self.bucket = self.s3.Bucket( BUCKET_NAME )


    def ls( self ):
        """
        bucketリストを取得する
        return : list型
        """

        return self.s3.buckets.all()



    def dl( self , path ):
        """
        Download
        """
        file_list = self.bucket.objects.all()
        print( Fore.YELLOW + "downloading from S3..." )
        print(Style.RESET_ALL)
        p = ProgressBar( 0, len( list( file_list ) ) )
        for i , key in enumerate( file_list ):
            filename = path + "/" + str( key.key )
            filename = filename.replace(" ","")
            dirname = os.path.dirname( filename )
            if not os.path.exists( dirname ): os.mkdir( dirname )
            if os.path.exists( filename ): continue
            try:
                self.bucket.download_file( key.key , filename )
            except Exception as e:
                print( Fore.RED + "Bad Format→" , filename )

            p.update( i )
        print(Fore.YELLOW +"Done!")
        print(Style.RESET_ALL)



#!-*-coding:utf-8-*-
import os
import sys
import MeCab
import numpy as np
sys.path.append("../")
import makinyan as mak
from pandas import Series
from sklearn.feature_extraction.text import TfidfVectorizer

__all__ = []
__all__ += ["tf","tfidf"]


def tfidf( mat ):
    """
    TF IDF
    """
    arr = []
    token = MeCab.Tagger("-O wakati")
    for m in mat:
        arr.append( token.parse(m) )

    vecliz = TfidfVectorizer(use_idf=True, token_pattern=u'(?u)\\b\\w+\\b')
    vecs = vecliz.fit_transform( arr )

    return vecs.toarray()


def tf( text ):
    """
    Term frequency
    """
    
    token = MeCab.Tagger("-O wakati")
    node = token.parseToNode(text)
    voc_mat = []
    while node:
        vocab = node.feature.split(",")[6]
        part = node.feature.split(",")[0]
        if part in ["名詞","固有名詞","動詞"]:
            voc_mat.append( vocab )

        node = node.next

    ser = Series( mak.group_hist( voc_mat ) )
    ser = ser.sort_values(ascending=False)

    return dict( ser )



#!-*-coding:utf-8-*-
from __future__ import absolute_import
from __future__ import unicode_literals
import os
from setuptools import setup,find_packages

#Get Readme
try:
    with open( 'README.rst' ) as f:
        readme = f.read()
except IOError:
    readme = ''


def _get_requirements( filename ):
    """
    Get all information of pre install required modules
    """
    return open(filename).read().splitlines()


pwd = os.path.dirname(os.path.abspath(__file__))
version = '0.0.22'

setup(
    name='makinyan',
    version=version,
    py_modules=['makinyan'],
    url='https://github.com/Shochan024/makinyan',
    author='shochan024',
    author_email='jadetech0024@gmail.com',
    maintainer='shochan024',
    maintainer_email='jadetech0024@gmail.com',
    description='Python Data Analitics Tool',
    long_description="readme",
    packages=find_packages(),
    install_requires=_get_requirements('requirements.txt'),
    license="MIT",
    classifiers=[
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'License :: OSI Approved :: MIT License',
    ],
    entry_points="""
        # -*- Entry points: -*-
        [console_scripts]
        pkgdep = pypipkg.scripts.command:main
    """,
)
